@@ -1,6 +1,5 @@
 `rLambertW` <-
-function(n, theta=c(0,0,1), distname="normal",
- innov=NULL, ZmUv=FALSE, ...) {
+function(n, theta=c(0,0,1), distname="normal", innov=NULL, ZmUv=FALSE) {
 
 if (length(theta) == 3 & distname=="t") stop("You must specify a degrees of freedom parameter for student-t input.")
 
@@ -20,7 +19,12 @@ if (distname=="t") {
 fac=sqrt(nu/(nu-2))
 x=rt(n, df=nu)/fac*sigma_x+mu_x
 }
-if (!is.null(innov)) x=innov
+
+if (!is.null(innov)) {
+x=innov
+mu_x=mean(x)
+sigma_x=sd(x)
+}
 
 u=(x-mu_x)/sigma_x
 z=u*exp(delta*u)
